
(_users_guide)=
# Users Guide


[Configuring the Model and Setting up Your Calculation](required_components.md)
: Information on how to set up the model for your specific calculation

[Calculating Weighting Functions](weighting_functions.md)
: How to calculate derivatives (weighting functions) of output quantities with respect to input quantities

[Built in Geodesy Tools](users_guide/geodetic.md)
: Methods to work with datums such as WGS84

[More Examples](examples/examples.rst)
: Miscallaneous examples of model usage


```{toctree}
:maxdepth: 4
:hidden:

required_components
weighting_functions
users_guide/polarization.md
users_guide/performance.md
users_guide/phase.md
users_guide/geodetic.md
examples/examples
```
